@@ -3,13 +3,13 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.1205';
+our $VERSION = '0.1206';
 
 use Moo;
 use strictures 2;
 use namespace::clean;
 
-use Imager;
+use Imager ();
 use List::SomeUtils 'first_index';
 use Music::Chord::Namer 'chordname';
 
@@ -101,12 +101,6 @@ has dot_color => (
 );
 
 
-has fretboard => (
-    is       => 'ro',
-    init_arg => undef,
-);
-
-
 has showname => (
     is      => 'rw',
     default => sub { 1 },
@@ -119,6 +113,12 @@ has verbose => (
 );
 
 
+has fretboard => (
+    is       => 'ro',
+    init_arg => undef,
+);
+
+
 sub BUILD {
     my ( $self, $args ) = @_;
 
@@ -485,49 +485,36 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.1205
+version 0.1206
 
 =head1 SYNOPSIS
 
   use Music::FretboardDiagram;
 
   my $dia = Music::FretboardDiagram->new(
-    chord => 'x02220',
-    font  => '/path/to/TTF/font.ttf',
+    chord   => 'x02220',
+    frets   => 13,
+    outfile => 'fretboard',
+    font    => '/path/to/TTF/font.ttf',
+    horiz   => 1,
+    verbose => 1,
   );
-  $dia->draw;
 
-  $dia->chord('xx0232');
-  $dia->position(5);
-  $dia->outfile('mystery-chord');
-  $dia->showname('Xb dim'); # "X flat diminished"
-  $dia->draw;
+  $dia->chord('xx0232');          # set a new chord
+  $dia->position(1);              # set a new position
+  $dia->outfile('mystery-chord'); # set a new filename
+  $dia->showname('Xb dim');       # "X flat diminished"
 
-  $dia = Music::FretboardDiagram->new(
-    chord    => '4442',
-    position => 3,
-    strings  => 4,
-    frets    => 6,
-    size     => 25,
-    outfile  => 'ukulele-chord',
-    type     => 'bmp',
-    font     => '/path/to/TTF/font.ttf',
-    tuning   => [qw/A E C G/],
-    horiz    => 1,
-    image    => 1,
-    verbose  => 1,
-    string_color => 'black',
-    fret_color   => 'darkgray',
-    dot_color    => 'blue',
-  );
-  my $image = $dia->draw;
+  $dia->draw;
 
 =head1 DESCRIPTION
 
-A C<Music::FretboardDiagram> object draws fretboard chord diagrams including
-neck position and chord name annotations for guitar, ukulele, banjo, etc.
+A C<Music::FretboardDiagram> object draws fretboard chord diagrams
+including neck position and chord name annotations for guitar,
+ukulele, banjo, etc.
 
-=for html Here are examples of a vertical guitar diagram and a horizontal ukulele diagram:
+=for html Here are examples of a vertical guitar diagram and a horizontal
+ukulele diagram:
 <br>
 <img src="https://raw.githubusercontent.com/ology/Music-FretboardDiagram/master/chord-diagram.png">
 <img src="https://raw.githubusercontent.com/ology/Music-FretboardDiagram/master/ukulele.png">
@@ -540,9 +527,10 @@ neck position and chord name annotations for guitar, ukulele, banjo, etc.
   $dia->chord('xx0232');
   $chord = $dia->chord;
 
-A chord given as a string, where non-zero digits represent frets, C<x> (or C<X>)
-indicates a muted string and C<0> (or C<o> or C<O>) indicates an open string.
-The default order of the strings is C<654321> from lowest to highest.
+A required chord given as a string, where non-zero digits represent
+frets, C<x> (or C<X>) indicates a muted string and C<0> (or C<o> or
+C<O>) indicates an open string.  The default order of the strings is
+C<654321> from lowest to highest.
 
 Examples:
 
@@ -570,16 +558,18 @@ Examples:
   A7: x02020
   B7: x21202
 
+  etc.
+
 =head2 position
 
   $dia->position(3);
   $position = $dia->position;
 
-The neck position of a chord to be diagrammed.  This number is rendered to the
-left of the first fret in vertical mode.  When drawing horizontally, the
-position is rendered above the first fret.
+The neck position of a chord to be diagrammed.  This number is
+rendered to the left of the first fret in vertical mode.  When drawing
+horizontally, the position is rendered above the first fret.
 
-Default: 1
+Default: C<1>
 
 =head2 strings
 
@@ -587,7 +577,7 @@ Default: 1
 
 The number of strings.
 
-Default: 6
+Default: C<6>
 
 =head2 frets
 
@@ -595,7 +585,7 @@ Default: 6
 
 The number of frets.
 
-Default: 5
+Default: C<5>
 
 =head2 size
 
@@ -603,7 +593,7 @@ Default: 5
 
 The relative size of the diagram.
 
-Default: 30
+Default: C<30>
 
 =head2 outfile
 
@@ -612,7 +602,7 @@ Default: 30
 
 The image file name minus the extension.
 
-Default: chord-diagram
+Default: C<chord-diagram>
 
 =head2 type
 
@@ -620,41 +610,44 @@ Default: chord-diagram
 
 The image file extension.
 
-Default: png
+Default: C<png>
 
 =head2 font
 
   $font = $dia->font;
 
-The TTF font to use when rendering the diagram.
+The (TTF) font.
 
-Default: /opt/X11/share/fonts/TTF/VeraMono.ttf
+Default: C</usr/share/fonts/truetype/freefont/FreeMono.ttf>
 
 =head2 tuning
 
   $tuning = $dia->tuning;
 
-An arrayref of the string tuning.  The order of the notes is from highest string
-(1st) to lowest (6th).  For accidental notes, use flat (C<b>), not sharp (C<#>).
+An arrayref of the string tuning.  The order of the notes is from
+highest string (1st) to lowest (6th).  For accidental notes, use flat
+(C<b>), not sharp (C<#>).
 
-Default: [ E B G D A E ]
+Default: C<[ E B G D A E ]>
 
 =head2 horiz
 
   $horiz = $dia->horiz;
 
-Draw the diagram horizontally.  That is, with the first string at the top and
-the 6th string at the bottom, and frets numbered from left to right.
+Draw the diagram horizontally.  That is, with the first string at the
+top and the 6th string at the bottom, and frets numbered from left to
+right.
 
-Default: 0
+Default: C<0>
 
 =head2 image
 
   $image = $dia->image;
 
-Return the image from the B<draw> method instead of writing to a file.
+Return the image from the B<draw> method instead of writing it to a
+file.
 
-Default: 0
+Default: C<0>
 
 =head2 string_color
 
@@ -662,7 +655,7 @@ Default: 0
 
 The diagram string color.
 
-Default: blue
+Default: C<blue>
 
 =head2 fret_color
 
@@ -670,7 +663,7 @@ Default: blue
 
 The diagram fret color.
 
-Default: darkgray
+Default: C<darkgray>
 
 =head2 dot_color
 
@@ -678,29 +671,22 @@ Default: darkgray
 
 The diagram finger position dot color.
 
-Default: black
-
-=head2 fretboard
-
-  $fretboard = $dia->fretboard;
-
-A hashref of the string notes.  This is a computed attribute based on the given
-B<tuning>.
+Default: C<black>
 
 =head2 showname
 
-  $dia->showname('Xb dim');
-  $dia->showname(1); # Reset to computed names
-  $dia->showname(0); # Do not show chord names
+  $dia->showname(0);        # Do not show chord names
+  $dia->showname(1);        # Show computed names
+  $dia->showname('Xb dim'); # Show a custom name
   $showname = $dia->showname;
 
 Show a chord name or not.
 
-Sometimes the computed chord name is not that accurate or desired.  In those
-cases either set the B<showname> to a string of your choosing before drawing, or
-to C<0> for no chord name.
+Sometimes the computed chord name is not accurate or desired.  In
+those cases, either set the B<showname> to a string of your choosing
+before drawing, or to C<0> for no chord name.
 
-Default: 1
+Default: C<1>
 
 =head2 verbose
 
@@ -708,13 +694,37 @@ Default: 1
 
 Monitor the progress of the diagram construction.
 
-Default: 0
+Default: C<0>
+
+=head2 fretboard
+
+  $fretboard = $dia->fretboard;
+
+A hashref of the string notes.  This is a computed attribute based on
+the given B<tuning>.
 
 =head1 METHODS
 
 =head2 new
 
-  $dia = Music::FretboardDiagram->new(%arguments);
+  $dia = Music::FretboardDiagram->new(
+    chord        => $chord,
+    position     => $position,
+    strings      => $strings,
+    frets        => $frets,
+    size         => $size,
+    tuning       => $tuning,
+    font         => $font,
+    showname     => $showname,
+    horiz        => $horiz,
+    image        => $image,
+    string_color => $string_color,
+    fret_color   => $fret_color,
+    dot_color    => $dot_color,
+    outfile      => $outfile,
+    type         => $type,
+    verbose      => $verbose,
+  );
 
 Create a new C<Music::FretboardDiagram> object.
 
@@ -723,8 +733,13 @@ Create a new C<Music::FretboardDiagram> object.
 =head2 draw
 
   $dia->draw;
+  $image = $dia->draw;
 
-Render the requested chord diagram as an image file of the given B<type>.
+Render the requested chord diagram as an image file of the given
+B<type>.
+
+If the C<image> attribute is set, return the image object instead of
+writing to a file.
 
 =head1 THANK YOU
 
@@ -758,7 +773,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Gene Boggs.
+This software is copyright (c) 2020 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
